@@ -13,7 +13,7 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use Net::GitHub;
 
-our $VERSION     = version->new('0.0.3');
+our $VERSION     = version->new('0.0.4');
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 #our @EXPORT      = qw//;
@@ -31,11 +31,23 @@ sub _repos {
     my ($self) = @_;
     my %repos = %{ $self->SUPER::_repos() };
 
-    for my $repo ( $self->github->repos->list ) {
-        $repos{ $repo->{name} } = Group::Git::Repo->new(
-            name => $repo->{name},
-            git  => $repo->{git_url},
-        );
+    my $repo = $self->github->repos;
+    my @list = $repo->list;
+    my $page = 1;
+    my $last_url = '';
+
+    while (@list) {
+        for my $repo (@list) {
+            $repos{ $repo->{name} } = Group::Git::Repo->new(
+                name => $repo->{name},
+                git  => $repo->{git_url},
+            );
+        }
+
+        last if !defined $last_url;
+
+        @list = $repo->next_page if $repo->has_next_page && $repo->next_url ne $last_url;
+        $last_url = $repo->next_url;
     }
 
     return \%repos;
@@ -61,7 +73,7 @@ Group::Git::Github - Adds reading all repositories you have access to on github
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Github version 0.0.3.
+This documentation refers to Group::Git::Github version 0.0.4.
 
 
 =head1 SYNOPSIS
